% Assumes databases are in NCMBase/database where NCMBase is ../../(Location of LoadNCMData script)
disp('Loading NCM data')

global geology age ageMin ageMax depth insert e bre me pe Top MCe LIDe
global x y mstruct LAv LOv jg kg nx ny nLay
global Top2 AgeCorr AgeH Conductivity SurfaceTemp SurfaceTempAve SurfaceTempGradient ...
       MohoTemp LIDe TransDepth TransDepthType TransDepthOcean TransDepthTypeOcean
global MNF1 MNF2 WTD Rock

dr = which('LoadNCMData');
k = strfind(dr,':');
if k == 2       % PC
	k = strfind(dr,'\');
else            % Mac
	k = strfind(dr,'/');
end
NCMBase = dr(1:k(length(k)-2));

addpath([NCMBase 'TherMod/matlab'])
addpath([NCMBase 'GeoFram/matlab'])
addpath([NCMBase 'MinVel/matlab'])
  
dBase = [NCMBase 'database/'];

x = ncread([dBase 'NCM_SpatialGrid.nc'],'x');
y = ncread([dBase 'NCM_SpatialGrid.nc'],'y');
mstruct.origin = [24 -95];
mstruct.mapparallels = [30 45];
mstruct.scalefactor = 0.9996;
mstruct.falsenorthing = 0;
mstruct.falseeasting = 0;
mstruct.geoid = [6378137.0 0.081819190842622];

LAv = ncread([dBase 'NCM_SpatialGrid.nc'],'Latitude vector');
LOv = ncread([dBase 'NCM_SpatialGrid.nc'],'Longitude vector');
jg = ncread([dBase 'NCM_SpatialGrid.nc'],'Index j grid');
kg = ncread([dBase 'NCM_SpatialGrid.nc'],'Index k grid');

e = ncread([dBase 'NCM_GeologicFrameworkGrids.nc'],'Surface Elevation');
bre = ncread([dBase 'NCM_GeologicFrameworkGrids.nc'],'Bedrock Elevation');
me = ncread([dBase 'NCM_GeologicFrameworkGrids.nc'],'Bottom Cenozoic Elevation');
pe = ncread([dBase 'NCM_GeologicFrameworkGrids.nc'],'Bottom Phanerozoic Elevation');
MCe = ncread([dBase 'NCM_GeologicFrameworkGrids.nc'],'Mid Crustal Elevation');
LIDe = ncread([dBase 'NCM_GeologicFrameworkGrids.nc'],'Moho Elevation');
Top = ncread([dBase 'NCM_GeologicFrameworkGrids.nc'],'Top Ocean Plate Elevation');

geology = ncread([dBase 'NCM_GeologicFrameworkVolume.nc'],'Rock Type Profile Index');
age = ncread([dBase 'NCM_GeologicFrameworkVolume.nc'],'Age Profile Index');
depth = ncread([dBase 'NCM_GeologicFrameworkVolume.nc'],'Layer Elevation');
rockLabel = ncread([dBase 'NCM_GeologicFrameworkVolume.nc'],'Rock Type Name');
ageLabel = ncread([dBase 'NCM_GeologicFrameworkVolume.nc'],'Age Name');
ageMax = ncread([dBase 'NCM_GeologicFrameworkVolume.nc'],'Age Max');
ageMin = ncread([dBase 'NCM_GeologicFrameworkVolume.nc'],'Age Min');

insert = uint8(zeros(size(geology)));
[nLay,ny,nx] = size(geology);

MohoTemp = ncread([dBase 'NCM_TemperatureGrids.nc'],'Moho Temperature');
SurfaceTemp = ncread([dBase 'NCM_TemperatureGrids.nc'],'Surface Temperature');
SurfaceTempAve = ncread([dBase 'NCM_TemperatureGrids.nc'],'Surface Temperature Average');
SurfaceTempGradient = ncread([dBase 'NCM_TemperatureGrids.nc'],'Surface Temperature Gradient');
Conductivity = ncread([dBase 'NCM_TemperatureGrids.nc'],'Conductivity');
Top2 = ncread([dBase 'NCM_TemperatureGrids.nc'],'Ocean Top Elevation Smooth');
Age2 = ncread([dBase 'NCM_TemperatureGrids.nc'],'Ocean Age');
AgeH = ncread([dBase 'NCM_TemperatureGrids.nc'],'Ocean Age Mask');
TransDepth = ncread([dBase 'NCM_TemperatureGrids.nc'],'Transition Depth');
TransDepthType = ncread([dBase 'NCM_TemperatureGrids.nc'],'Transition Depth Type');
TransDepthOcean = ncread([dBase 'NCM_TemperatureGrids.nc'],'Transition Depth Ocean');
TransDepthTypeOcean = ncread([dBase 'NCM_TemperatureGrids.nc'],'Transition Depth Type Ocean');

WTD = ncread([dBase 'NCM_AuxData.nc'],'Water Table Depth');
MNF1 = ncread([dBase 'NCM_AuxData.nc'],'Calibration Slope');
MNF2 = ncread([dBase 'NCM_AuxData.nc'],'Calibration Offset');
mi = ncread([dBase 'PetrologyDatabase.nc'],'Mineral Index');
vf = ncread([dBase 'PetrologyDatabase.nc'],'Volume Fraction');

MNF1(211:212) = 0;
MNF2(211:212,:) = -5;

for j = 1:210
	k = find(mi(j,:) > 0);
	Rock(j).MinIndex = mi(j,k);
	Rock(j).VolFrac = vf(j,k);
end
Rock(211).MinIndex = mi(211,1);
Rock(211).VolFrac = vf(211,1);
Rock(212).MinIndex = mi(212,1);
Rock(212).VolFrac = vf(212,1);

j = find(Top2 > e);
Top2(j) = e(j);

l1 = 9+((80-9)/80)*Age2;
l2 = 80*ones(size(Age2));
AgeCorr = 1./((1./l1).^10 + (1./l2).^10);
AgeCorr = AgeCorr.^(1/10);

clear l1 l2 j Age2
